@@ -1,4 +1,5 @@
 import hashlib
+import inspect
 import os
 import types
 from importlib import import_module
@@ -42,6 +43,10 @@ class TaskOnKart(luigi.Task):
                                                   description='If this is true, this task will not run only if all input and output files exist,'
                                                   ' and all input files are modified before output file are modified.',
                                                   significant=False)
+    serialized_task_definition_check = luigi.BoolParameter(default=False,
+                                                           description='If this is true, even if all outputs are present,'
+                                                           'this task will be executed if any changes have been made to the code.',
+                                                           significant=False)
     delete_unnecessary_output_files = luigi.BoolParameter(default=False, description='If this is true, delete unnecessary output files.', significant=False)
     significant = luigi.BoolParameter(default=True,
                                       description='If this is false, this task is not treated as a part of dependent tasks for the unique id.',
@@ -210,6 +215,7 @@ class TaskOnKart(luigi.Task):
                                                redis_params=redis_params)
 
     def load(self, target: Union[None, str, TargetOnKart] = None) -> Any:
+
         def _load(targets):
             if isinstance(targets, list) or isinstance(targets, tuple):
                 return [_load(t) for t in targets]
@@ -223,6 +229,7 @@ class TaskOnKart(luigi.Task):
         return data
 
     def load_generator(self, target: Union[None, str, TargetOnKart] = None) -> Any:
+
         def _load(targets):
             if isinstance(targets, list) or isinstance(targets, tuple):
                 for t in targets:
@@ -239,6 +246,7 @@ class TaskOnKart(luigi.Task):
                         target: Union[None, str, TargetOnKart] = None,
                         required_columns: Optional[Set[str]] = None,
                         drop_columns: bool = False) -> pd.DataFrame:
+
         def _flatten_recursively(dfs):
             if isinstance(dfs, list):
                 return pd.concat([_flatten_recursively(df) for df in dfs])
@@ -265,6 +273,19 @@ class TaskOnKart(luigi.Task):
             assert not obj.empty
         self._get_output_target(target).dump(obj, lock_at_dump=self._lock_at_dump)
 
+    @staticmethod
+    def get_code(target_class) -> Set[str]:
+
+        def has_sourcecode(obj):
+            return inspect.ismethod(obj) or inspect.isfunction(obj) or inspect.isframe(obj) or inspect.iscode(obj)
+
+        return {inspect.getsource(t) for _, t in inspect.getmembers(target_class, has_sourcecode)}
+
+    def get_own_code(self):
+        gokart_codes = self.get_code(TaskOnKart)
+        own_codes = self.get_code(self)
+        return ''.join(sorted(list(own_codes - gokart_codes)))
+
     def make_unique_id(self):
         unique_id = self.task_unique_id or self._make_hash_id()
         if self.cache_unique_id:
@@ -272,15 +293,22 @@ class TaskOnKart(luigi.Task):
         return unique_id
 
     def _make_hash_id(self):
+
         def _to_str_params(task):
             if isinstance(task, TaskOnKart):
                 return str(task.make_unique_id()) if task.significant else None
+
+            if not isinstance(task, luigi.Task):
+                raise ValueError(f"Task.requires method returns {type(task)}. You should return luigi.Task.")
+
             return task.to_str_params(only_significant=True)
 
         dependencies = [_to_str_params(task) for task in luigi.task.flatten(self.requires())]
         dependencies = [d for d in dependencies if d is not None]
         dependencies.append(self.to_str_params(only_significant=True))
         dependencies.append(self.__class__.__name__)
+        if self.serialized_task_definition_check:
+            dependencies.append(self.get_own_code())
         return hashlib.md5(str(dependencies).encode()).hexdigest()
 
     def _get_input_targets(self, target: Union[None, str, TargetOnKart]) -> Union[TargetOnKart, List[TargetOnKart]]:
